@@ -5,7 +5,8 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 require Exporter; require AutoLoader; @ISA = qw(Exporter AutoLoader);
 @EXPORT = qw(); @EXPORT_OK = qw(t trace d dmp);
-use vars '$VERSION'; $VERSION = '1.1';
+use vars '$VERSION';
+$VERSION = '1.2';
 
 use FileHandle;
 
@@ -215,7 +216,7 @@ sub check_argv() {
 
 =head1 AUTHOR
 
-Ed Avis, epa98@doc.ic.ac.uk
+Ed Avis, ed@membled.com
 
 =head1 SEE ALSO
 
